@@ -11,18 +11,16 @@ import (
 
 	"github.com/operator-framework/operator-marketplace/pkg/metrics"
 	"github.com/operator-framework/operator-marketplace/pkg/migrator"
-	"github.com/operator-framework/operator-marketplace/pkg/operatorsource"
 
 	apiconfigv1 "github.com/openshift/api/config/v1"
-	olm "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/lib/signals"
 	"github.com/operator-framework/operator-marketplace/pkg/apis"
 	configv1 "github.com/operator-framework/operator-marketplace/pkg/apis/config/v1"
+	olm "github.com/operator-framework/operator-marketplace/pkg/apis/olm/v1alpha1"
 	"github.com/operator-framework/operator-marketplace/pkg/controller"
 	"github.com/operator-framework/operator-marketplace/pkg/controller/options"
 	"github.com/operator-framework/operator-marketplace/pkg/defaults"
 	"github.com/operator-framework/operator-marketplace/pkg/operatorhub"
-	"github.com/operator-framework/operator-marketplace/pkg/registry"
 	"github.com/operator-framework/operator-marketplace/pkg/status"
 	sourceCommit "github.com/operator-framework/operator-marketplace/pkg/version"
 	"github.com/operator-framework/operator-sdk/pkg/k8sutil"
@@ -30,6 +28,7 @@ import (
 	sdkVersion "github.com/operator-framework/operator-sdk/version"
 	log "github.com/sirupsen/logrus"
 	"k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
+	k8sErrors "k8s.io/apimachinery/pkg/api/errors"
 	kruntime "k8s.io/apimachinery/pkg/runtime"
 	_ "k8s.io/client-go/plugin/pkg/client/auth/gcp"
 	"k8s.io/client-go/rest"
@@ -63,10 +62,8 @@ func main() {
 	printVersion()
 
 	// Parse the command line arguments
-	flag.StringVar(&registry.ServerImage, "registryServerImage",
-		registry.DefaultServerImage, "the image to use for creating the operator registry pod")
 	flag.StringVar(&defaults.Dir, "defaultsDir",
-		"", "the directory where the default OperatorSources are stored")
+		"", "the directory where the default CatalogSources are stored")
 	var clusterOperatorName string
 	flag.StringVar(&clusterOperatorName, "clusterOperatorName", "", "the name of the OpenShift ClusterOperator that should reflect this operator's status, or the empty string to disable ClusterOperator updates")
 	flag.Parse()
@@ -123,8 +120,6 @@ func main() {
 
 	log.Print("Registering Components.")
 
-	registrySyncer := operatorsource.NewRegistrySyncer(mgr.GetClient(), initialWait, resyncInterval)
-
 	// Setup Scheme for all defined resources
 	if err := apis.AddToScheme(mgr.GetScheme()); err != nil {
 		exit(err)
@@ -155,8 +150,14 @@ func main() {
 		}
 	}
 
+	// Populate the global default OperatorSources definition and config
+	err = defaults.PopulateGlobals()
+	if err != nil {
+		exit(err)
+	}
+
 	// Setup all Controllers
-	if err := controller.AddToManager(mgr, options.ControllerOptions{SyncSender: statusReporter}); err != nil {
+	if err := controller.AddToManager(mgr, options.ControllerOptions{}); err != nil {
 		exit(err)
 	}
 
@@ -179,20 +180,14 @@ func main() {
 
 	// migrate away from Marketplace API
 	clientGo, err := client.New(cfg, client.Options{Scheme: mgr.GetScheme()})
-	if err != nil {
+	if err != nil && !k8sErrors.IsNotFound(err) {
 		log.Error(err, "Failed to instantiate client for migrator")
 		os.Exit(1)
 	}
 	migrator := migrator.New(clientGo)
 	err = migrator.Migrate()
 	if err != nil {
-		log.Error(err, "[migration] Error in migrating Marketplace away from CatalogSourceConfig API")
-	}
-
-	// Populate the global default OperatorSources definition and config
-	err = defaults.PopulateGlobals()
-	if err != nil {
-		exit(err)
+		log.Error(err, "[migration] Error in migrating Marketplace away from OperatorSource API")
 	}
 
 	// Handle the defaults
@@ -208,8 +203,6 @@ func main() {
 	// statusReportingDoneCh will be closed after the operator has successfully stopped reporting ClusterOperator status.
 	statusReportingDoneCh := statusReporter.StartReporting()
 
-	go registrySyncer.Sync(stopCh)
-
 	// Start the Cmd
 	err = mgr.Start(stopCh)
 
